const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    let record = this.findOrCreateLineItem(context); 

    Mesa.output.next(record);
  }

  findOrCreateLineItem = (context) => { 
    let shopifyLineItem = context.steps.loop;
    let order = context.steps.shopify_2;
    // Add your custom code here
    let options = {
      "headers": {
        "Content-Type": "application\/json",
        "Authorization": "Bearer " + Mesa.credential.get('airtable'),
      }
    }

    let filterByFormula = `{Line Item ID} = '${shopifyLineItem.id}'`;
    let base = context.steps.transform.base;
    let table = context.steps.transform.table;
    let url = 'https://api.airtable.com/v0/' + base + '/' + table + '?filterByFormula=' + encodeURIComponent(filterByFormula);

    let results = Mesa.request.get(url, options);    
    Mesa.log.info("results", results);

    if (results.records.length > 0) {
      return results.records[0];
    } 
    
    let data = {
      "records": [
        {
          "fields": {
            "Line Item ID": shopifyLineItem.id,
            "Order Name": order.name,
          },
        }
      ],
      "typecast": true,
    }
    
    let result = Mesa.request.post(url, data, options);
    Mesa.log.info('result', result);
    let newRecord = result.records[0];

    return newRecord;
  }
}
